/*
    This file is part of Choqok, the KDE micro-blogging client

    Copyright (C) 2010-2012 Andrey Esin <gmlastik@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/
*/

#include "coinurl.h"
#include <QString>
#include <KIO/Job>
#include <KDebug>
#include <kio/netaccess.h>
#include <KAboutData>
#include <KGenericFactory>
#include "notifymanager.h"
#include "coinurl_settings.h"
#include <passwordmanager.h>

K_PLUGIN_FACTORY( MyPluginFactory, registerPlugin < Coinurl > (); )
K_EXPORT_PLUGIN( MyPluginFactory( "choqok_coinurl" ) )

Coinurl::Coinurl( QObject* parent, const QVariantList& )
    : Choqok::Shortener( MyPluginFactory::componentData(), parent )
{
}

Coinurl::~Coinurl()
{
}

QString Coinurl::shorten( const QString& url )
{
    kDebug() << "Using coinurl";
    QByteArray data;
    // https://coinurl.com/api.php?uuid={$uuid}&url={$url}"
    KUrl reqUrl( "https://coinurl.com/api.php" );
    Coinurl_Settings::self()->readConfig();
    QString userApiKey = Choqok::PasswordManager::self()->readPassword( QString("coinurl") );
    if( !userApiKey.isEmpty() ){
        reqUrl.addQueryItem( "uuid", userApiKey );
    }

    reqUrl.addQueryItem( "url", KUrl( url ).url() );

    KIO::Job* job = KIO::get( reqUrl, KIO::Reload, KIO::HideProgressInfo );

    if( KIO::NetAccess::synchronousRun( job, 0, &data ) ) {
        QString output(data);
        kDebug() << "Short url is: " << output;
        QRegExp rx( QString( "(http://((.*)+)/([a-zA-Z0-9])+)" ) );
        rx.indexIn( output );
        QString coinurlUrl = rx.cap( 0 );
        if( !coinurlUrl.isEmpty() )
            return coinurlUrl;

        Choqok::NotifyManager::error( QString( data ), i18n( "coinurl.com error" ) );
    }
    else {
        Choqok::NotifyManager::error( job->errorString(), i18n( "coinurl.com error" ) );
    }
    return url;
}
