/*
    This file is part of Choqok, the KDE micro-blogging client

    Copyright (C) 2010-2012 Andrey Esin <gmlastik@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/

*/

#include "coinurl_config.h"
#include <KPluginFactory>
#include <KAboutData>
#include <KGenericFactory>
#include <KMessageBox>
#include <KIO/Job>
#include <kio/netaccess.h>
#include <klocale.h>
#include <qlayout.h>
#include <passwordmanager.h>
#include "coinurl_settings.h"
#include "notifymanager.h"

K_PLUGIN_FACTORY( Coinurl_ConfigFactory, registerPlugin < Coinurl_Config > (); )
K_EXPORT_PLUGIN( Coinurl_ConfigFactory( "kcm_choqok_coinurl" ) )

Coinurl_Config::Coinurl_Config(QWidget* parent, const QVariantList& ):
        KCModule( Coinurl_ConfigFactory::componentData(), parent)
{
    QVBoxLayout *layout = new QVBoxLayout(this);
    QWidget *wd = new QWidget(this);
    wd->setObjectName("mCoinurlCtl");
    wd->setMinimumWidth(400);
    ui.setupUi(wd);
    addConfig( Coinurl_Settings::self(), wd );
    layout->addWidget(wd);

    QRegExp rx( "([a-z0-9_]){1,22}", Qt::CaseInsensitive );
    QValidator *val0 = new QRegExpValidator( rx, 0 );
    ui.kcfg_api_key->setValidator( val0 );

    ui.help_label->setTextFormat( Qt::RichText );
    ui.help_label->setText( i18n("You can find your API key <a href=\"https://coinurl.com/profile.php\">here</a>") );

    connect( ui.kcfg_api_key, SIGNAL( textChanged( QString ) ), SLOT( emitChanged() ) );
}

Coinurl_Config::~Coinurl_Config()
{
}

void Coinurl_Config::load()
{
    kDebug();
    KCModule::load();
    KConfigGroup grp( KGlobal::config(), "Coinurl.com Shortener" );
    ui.kcfg_api_key->setText( Choqok::PasswordManager::self()->readPassword( QString("coinurl") ) );
}

void Coinurl_Config::save()
{
    kDebug();
    KCModule::save();
    KConfigGroup grp( KGlobal::config(), "Coinurl.com Shortener" );
    Choqok::PasswordManager::self()->writePassword( QString( "coinurl" ),
                                                   ui.kcfg_api_key->text());
}

void Coinurl_Config::emitChanged()
{
    emit changed( true );
}

#include "coinurl_config.moc"
